==> custom_pages-v1.12.9.zip: custom_pages/messages/pt/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>Adicionar</strong> item {templateName}',
    '<strong>Custom</strong> Pages' => 'Páginas <strong>personalizáveis</strong>',
    '<strong>Edit</strong> snippet' => '<strong>Editar</strong> trecho',
    'Add' => 'Adicionar',
    'Add a file icon before the title' => 'Adicionar um ícone de ficheiro antes do título',
    'Adds plain HTML content to your site.' => 'Adiciona conteúdo em HTML simples ao teu site.',
    'Advanced' => 'Avançado',
    'Allows the user to manage custom pages.' => 'Permite a utentes gerir páginas personalizadas.',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Permite adicionar páginas (Markdown, ifram ou ligações) à navegação do espaço',
    'Allows you to add content in MarkDown syntax.' => 'Permite-te adicionar conteúdo em sintaxe Markdown.',
    'Alternate text' => 'Alternar texto',
    'Always make a backup of your view files outside of your production environment!' => 'Faz sempre uma salvaguarda dos teus ficheiros fora do teu ambiente de produção!',
    'An empty allowed template selection will allow all container templates for this container.' => 'Uma seleção de modelo permitido vazia irá permitir todos os modelos.',
    'Back' => 'Voltar',
    'Back to dashboard' => 'Voltar para o painel',
    'Back to overview' => 'Voltar à vista geral',
    'Back to space' => 'Voltar ao espaço',
    'Can manage custom pages' => 'Pode gerir páginas personalizáveis',
    'Category' => 'Categoria',
    'Configuration' => 'Configuração',
    'Content' => 'Conteúdo',
    'Create' => 'Criar',
    'Css Class' => 'Classe CSS',
    'Custom' => 'Modificável',
    'Custom Pages' => 'Páginas Personalizáveis',
    'Custom pages' => 'Páginas personalizáveis',
    'Dashboard' => 'Painel',
    'Default' => 'Padrão',
    'Default Content' => 'Conteúdo padrão',
    'Delete' => 'Apagar',
    'Edit' => 'Editar',
    'Edit Page' => 'Editar Página',
    'Empty' => 'Vazio',
    'File' => 'Ficheiro',
    'Footer menu' => 'Menu de rodapé',
    'General' => 'Geral',
    'Html' => 'HTML',
    'ID' => 'ID',
    'Icon' => 'Ícone',
    'Iframe' => 'Iframe',
    'Insert' => 'Inserir',
    'Invalid request data!' => 'Pedido inválido!',
    'Invalid template selection!' => 'Seleção de modelo inválida!',
    'Invalid type selection' => 'Seleção de tipo inválida',
    'Invalid view file selection!' => 'Seleção de vista de ficheiro inválida!',
    'Link' => 'Ligaçãp',
    'MarkDown' => 'Markdown',
    'Menu settings' => 'Definições do menu',
    'Navigation' => 'Navegação',
    'On this page you can configure general settings of your custom pages.' => 'Nesta página podes configurar as definições gerais das tuas páginas personalizáveis.',
    'Overview' => 'Visão geral',
    'PHP' => 'PHP',
    'Page' => 'Página',
    'Pages' => 'Páginas',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => 'Por favor escolhe um dos seguintes tipos de conteúdo. O tipo de conteúdo define como o teu conteúdo é incorporado no teu sítio.',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Por favor lembra-te que páginas baseadas em PHP são vulneráveis a questões de segurança, especialmente quando lidam com dados intorduzidos por utentes. Para mais informação, por favor consulta as <a href="{url}">boas práticas de segurança em Yii</a>.',
    'Public' => 'Público',
    'Reset' => 'Recomeçar',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => 'Escolher esta definição para nodos de texto visíveis. Não selecionar esta definição no caso deste elemento ser usado, por exemplo, como um valor de atributo HTML.',
    'Settings' => 'Definições',
    'Show additional file information (size)' => 'Mostrar informação adicional do ficheiro (tamanho)',
    'Snippet' => 'Excerto',
    'Snippets' => 'Excertos',
    'Sort Order' => 'Ordem',
    'Source' => 'Fonte',
    'Space' => 'Espaço',
    'Space Members only' => 'Apenas Participantes do espaço',
    'Space Navigation' => 'Navegação do Espaço',
    'Spaces' => 'Espaços',
    'Stream' => '<em>Stream</em>',
    'Stream options' => 'Opções do mural',
    'Style' => 'Estilo',
    'Style Class' => 'Classe de Estilo',
    'Submit' => 'Enviar',
    'Target Url' => 'URL alvo',
    'Template' => 'Modelo',
    'Template Layout' => '<em>Layout</em> do modelo',
    'Templates' => 'Modelos',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Os Modelos permitem-te definir fragmentos de páginas combináveis com funcionalidade de edição em linha.',
    'This container does not allow any further items!' => 'Este <em>container</em> não permite mais nenhum item!',
    'Title' => 'Título',
    'Top Navigation' => 'Navegação de topo',
    'Topics' => 'Tópicos',
    'Type' => 'Tipo',
    'Upload image' => 'Carregar imagem',
    'User Account Menu (Settings)' => 'Menu de Conta (Definições)',
    'Visibility' => 'Visibilidade',
    'Will embed the result of a given url as an iframe element.' => 'Vai incorporar o resultado de um dado URL como um elemento iframe.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Irá redirecionar pedidos para um dado URL (relativo ou absoluto).',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'Com páginas baseadas em PHP podes criar páginas personalizáveis por meio de ficheiros de vista no teu sistema de ficheiros. Por favor verifica a configuração do módulo para mais informação.',
    'Without adding to navigation (Direct link)' => 'Sem adicionar à navegação (ligação directa)',
    'You are not allowed to delete default content!' => 'Não estás autorizado a apagar conteúdo padrão!',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Always' => '',
    'Authors' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Deleted.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Import' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Non-Logged-In Users' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Start Page' => '',
    'Usage' => '',
    'Wrap this HTML page with white panel' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/pt/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>Adicionar</strong> item {templateName}',
    '<strong>Custom</strong> Pages' => 'Páginas <strong>personalizáveis</strong>',
    '<strong>Edit</strong> snippet' => '<strong>Editar</strong> trecho',
    'Add' => 'Adicionar',
    'Add a file icon before the title' => 'Adicionar um ícone de ficheiro antes do título',
    'Adds plain HTML content to your site.' => 'Adiciona conteúdo em HTML simples ao teu site.',
    'Advanced' => 'Avançado',
    'Allows the user to manage custom pages.' => 'Permite a utentes gerir páginas personalizadas.',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Permite adicionar páginas (Markdown, ifram ou ligações) à navegação do espaço',
    'Allows you to add content in MarkDown syntax.' => 'Permite-te adicionar conteúdo em sintaxe Markdown.',
    'Alternate text' => 'Alternar texto',
    'Always make a backup of your view files outside of your production environment!' => 'Faz sempre uma salvaguarda dos teus ficheiros fora do teu ambiente de produção!',
    'An empty allowed template selection will allow all container templates for this container.' => 'Uma seleção de modelo permitido vazia irá permitir todos os modelos.',
    'Back' => 'Voltar',
    'Back to dashboard' => 'Voltar para o painel',
    'Back to overview' => 'Voltar à vista geral',
    'Back to space' => 'Voltar ao espaço',
    'Can manage custom pages' => 'Pode gerir páginas personalizáveis',
    'Category' => 'Categoria',
    'Configuration' => 'Configuração',
    'Content' => 'Conteúdo',
    'Create' => 'Criar',
    'Css Class' => 'Classe CSS',
    'Custom' => 'Modificável',
    'Custom Pages' => 'Páginas Personalizáveis',
    'Custom pages' => 'Páginas personalizáveis',
    'Dashboard' => 'Painel',
    'Default' => 'Padrão',
    'Default Content' => 'Conteúdo padrão',
    'Delete' => 'Apagar',
    'Edit' => 'Editar',
    'Edit Page' => 'Editar Página',
    'Empty' => 'Vazio',
    'File' => 'Ficheiro',
    'Footer menu' => 'Menu de rodapé',
    'General' => 'Geral',
    'Html' => 'HTML',
    'ID' => 'ID',
    'Icon' => 'Ícone',
    'Iframe' => 'Iframe',
    'Insert' => 'Inserir',
    'Invalid request data!' => 'Pedido inválido!',
    'Invalid template selection!' => 'Seleção de modelo inválida!',
    'Invalid type selection' => 'Seleção de tipo inválida',
    'Invalid view file selection!' => 'Seleção de vista de ficheiro inválida!',
    'Link' => 'Ligaçãp',
    'MarkDown' => 'Markdown',
    'Menu settings' => 'Definições do menu',
    'Navigation' => 'Navegação',
    'On this page you can configure general settings of your custom pages.' => 'Nesta página podes configurar as definições gerais das tuas páginas personalizáveis.',
    'Overview' => 'Visão geral',
    'PHP' => 'PHP',
    'Page' => 'Página',
    'Pages' => 'Páginas',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => 'Por favor escolhe um dos seguintes tipos de conteúdo. O tipo de conteúdo define como o teu conteúdo é incorporado no teu sítio.',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Por favor lembra-te que páginas baseadas em PHP são vulneráveis a questões de segurança, especialmente quando lidam com dados intorduzidos por utentes. Para mais informação, por favor consulta as <a href="{url}">boas práticas de segurança em Yii</a>.',
    'Public' => 'Público',
    'Reset' => 'Recomeçar',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => 'Escolher esta definição para nodos de texto visíveis. Não selecionar esta definição no caso deste elemento ser usado, por exemplo, como um valor de atributo HTML.',
    'Settings' => 'Definições',
    'Show additional file information (size)' => 'Mostrar informação adicional do ficheiro (tamanho)',
    'Snippet' => 'Excerto',
    'Snippets' => 'Excertos',
    'Sort Order' => 'Ordem',
    'Source' => 'Fonte',
    'Space' => 'Espaço',
    'Space Members only' => 'Apenas Participantes do espaço',
    'Space Navigation' => 'Navegação do Espaço',
    'Spaces' => 'Espaços',
    'Stream' => '<em>Stream</em>',
    'Stream options' => 'Opções do mural',
    'Style' => 'Estilo',
    'Style Class' => 'Classe de Estilo',
    'Submit' => 'Enviar',
    'Target Url' => 'URL alvo',
    'Template' => 'Modelo',
    'Template Layout' => '<em>Layout</em> do modelo',
    'Templates' => 'Modelos',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Os Modelos permitem-te definir fragmentos de páginas combináveis com funcionalidade de edição em linha.',
    'This container does not allow any further items!' => 'Este <em>container</em> não permite mais nenhum item!',
    'Title' => 'Título',
    'Top Navigation' => 'Navegação de topo',
    'Topics' => 'Tópicos',
    'Type' => 'Tipo',
    'Upload image' => 'Carregar imagem',
    'User Account Menu (Settings)' => 'Menu de Conta (Definições)',
    'Visibility' => 'Visibilidade',
    'Will embed the result of a given url as an iframe element.' => 'Vai incorporar o resultado de um dado URL como um elemento iframe.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Irá redirecionar pedidos para um dado URL (relativo ou absoluto).',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'Com páginas baseadas em PHP podes criar páginas personalizáveis por meio de ficheiros de vista no teu sistema de ficheiros. Por favor verifica a configuração do módulo para mais informação.',
    'Without adding to navigation (Direct link)' => 'Sem adicionar à navegação (ligação directa)',
    'You are not allowed to delete default content!' => 'Não estás autorizado a apagar conteúdo padrão!',
    'Activities' => '',
    'Activity' => '',
    'Activity content ID' => '',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Always' => '',
    'Authors' => '',
    'By creation date' => '',
    'By last update' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Deleted.' => '',
    'Determine which Spaces should be taken into account.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Import' => '',
    'Include all Spaces except selected' => '',
    'Include selected Spaces only' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Non-Logged-In Users' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Sorting' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Space selection' => '',
    'Start Page' => '',
    'Usage' => '',
    'Wrap this HTML page with white panel' => '',
];
